View source: R/processConcordance.R
| processLatexConcordance | R Documentation |
Pandoc can record concordance information in \datapos macros
when converting Commonmark documents to LaTeX. This retrieves
that information, and rewrites it as standard R concordance
data.
processLatexConcordance(filename,
newfilename = filename,
rename = NULL,
followConcordance = NULL,
defineSconcordance = TRUE)
filename |
The filename of the LaTeX file produced by Pandoc. |
newfilename |
A filename in which to write the changed data. |
rename |
A named character vector. Names are the names in the |
followConcordance |
If |
defineSconcordance |
Whether to insert the definition of the |
Called for the side effect of rewriting the concordance, it returns
newfilename invisibly.
Duncan Murdoch
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.